Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetShellCommand ¶
GetShellCommand returns the command and arguments to execute the shell
func GetShellDescription ¶
GetShellDescription returns a description for the given shell type
Types ¶
type ShellType ¶
type ShellType int
ShellType represents the type of shell to use for command execution
func DetectShell ¶
DetectShell determines the best available shell for the current platform
func ParseShellType ¶
ParseShellType converts a shell type string (e.g. "bash", "powershell", "git-bash", "posix") back to a ShellType. Unknown values fall back to bash.
Click to show internal directories.
Click to hide internal directories.